==> moonkake-8.5.31.tgz: package/src/js/libs/validation.js <==
import validate from 'validate.js'

const isEmpty = obj => obj && Object.keys(obj).length === 0 && obj.constructor === Object

const defaultSchema = {
	email: {
		email: true
	},
	phone: {
		length: {
			is: 18
		}
	}
}

class Validation {
	constructor(selector = 'form', schema = {}, options = {}) {
		if (typeof selector !== 'string') {
			console.error('[Validation] Selector must be string')
			return
		}

		this.$form = document.querySelector(selector)

		if (!this.$form) {
			console.error('[Validation] Form not found')
			return
		}

		this.options = {
			selectors: 'input, select, textarea',
			events: 'change, input, blur',
			classNames: {
				root: 'field',
				error: 'field_error',
				success: 'field_success',
			}
		}

		if (typeof options === 'object') {
			this.options = { ...this.options, ...options }
		}

		this.schema = !isEmpty(schema) ? schema : defaultSchema

		this.#addListeners()
	}

	#addListeners() {
		this.$form.querySelectorAll(this.options.selectors).forEach($field => {
			const events = this.options.events.split(',')

			events.forEach(event => $field.addEventListener(event, this.validate($field).bind(this)))
		})
	}

	validate($el) {
		if (!this.schema[$el.name]) return

		const values = validate.collectFormValues(this.$form)
		const errors = validate.single(values[$el.name], this.schema[$el.name])

		const $field = $el.closest(`.${this.options.classNames.root}`)

		if (errors) {
			$field.classList.add(this.options.classNames.error)
			$field.classList.remove(this.options.classNames.success)
		} else {
			$field.classList.remove(this.options.classNames.error)
			$field.classList.add(this.options.classNames.success)
		}
	}
}

export default Validation

==> moonkake-8.5.71.tgz: package/src/js/libs/validation.js <==
import validate from 'validate.js'

const isEmpty = obj => obj && Object.keys(obj).length === 0 && obj.constructor === Object

const defaultSchema = {
	email: {
		email: true
	},
	phone: {
		length: {
			is: 18
		}
	}
}

class Validation {
	constructor(selector = 'form', schema = {}, options = {}) {
		if (typeof selector !== 'string') {
			console.error('[Validation] Selector must be string')
			return
		}

		this.$form = document.querySelector(selector)

		if (!this.$form) {
			console.error('[Validation] Form not found')
			return
		}

		this.options = {
			selectors: 'input, select, textarea',
			events: 'change, input, blur',
			classNames: {
				root: 'field',
				error: 'field_error',
				success: 'field_success'
			}
		}

		if (typeof options === 'object') {
			this.options = { ...this.options, ...options }
		}

		this.schema = !isEmpty(schema) ? schema : defaultSchema

		this.#addListeners()
	}

	#addListeners() {
		this.$form.querySelectorAll(this.options.selectors).forEach($field => {
			const events = this.options.events.split(',')

			events.forEach(event => $field.addEventListener(event, this.validate($field).bind(this)))
		})
	}

	validate($el) {
		if (!this.schema[$el.name]) return

		const values = validate.collectFormValues(this.$form)
		const errors = validate.single(values[$el.name], this.schema[$el.name])

		const $field = $el.closest(`.${this.options.classNames.root}`)

		if (errors) {
			$field.classList.add(this.options.classNames.error)
			$field.classList.remove(this.options.classNames.success)
		} else {
			$field.classList.remove(this.options.classNames.error)
			$field.classList.add(this.options.classNames.success)
		}
	}
}

export default Validation
